/*
* JBoss, the OpenSource J2EE webOS
*
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/
package org.jboss.test.webservice.marshalltest;

/**
 * Service interface for MarshallRpcBean.
 */
public interface MarshallRpcServiceInterface
   extends java.rmi.Remote
{

   public java.lang.String echoString( java.lang.String v )
      throws java.rmi.RemoteException;

   public java.math.BigInteger echoInteger( java.math.BigInteger v )
      throws java.rmi.RemoteException;

   public int echoInt( int v )
      throws java.rmi.RemoteException;

   public long echoLong( long v )
      throws java.rmi.RemoteException;

   public short echoShort( short v )
      throws java.rmi.RemoteException;

   public java.math.BigDecimal echoDecimal( java.math.BigDecimal v )
      throws java.rmi.RemoteException;

   public float echoFloat( float v )
      throws java.rmi.RemoteException;

   public double echoDouble( double v )
      throws java.rmi.RemoteException;

   public boolean echoBoolean( boolean v )
      throws java.rmi.RemoteException;

   public byte echoByte( byte v )
      throws java.rmi.RemoteException;

   public javax.xml.namespace.QName echoQName( javax.xml.namespace.QName v )
      throws java.rmi.RemoteException;

   public java.util.Calendar echoDateTimeCalendar( java.util.Calendar v )
      throws java.rmi.RemoteException;
   
   public java.util.Date echoDateTimeDate( java.util.Date v )
      throws java.rmi.RemoteException;

   public java.util.Calendar echoDateCalendar( java.util.Calendar v )
      throws java.rmi.RemoteException;

   public java.util.Date echoDateDate( java.util.Date v )
      throws java.rmi.RemoteException;

   public byte[] echoBase64Binary( byte[] v )
      throws java.rmi.RemoteException;

   public byte[] echoHexBinary( byte[] v )
      throws java.rmi.RemoteException;

   public org.jboss.test.webservice.marshalltest.types.Bean echoBean( org.jboss.test.webservice.marshalltest.types.Bean bean )
      throws java.rmi.RemoteException;

   public java.lang.String[] echoStringArray( java.lang.String[] v )
      throws java.rmi.RemoteException;

   public java.math.BigInteger[] echoIntegerArray( java.math.BigInteger[] v )
      throws java.rmi.RemoteException;

   public int[] echoIntArray( int[] v )
      throws java.rmi.RemoteException;

   public long[] echoLongArray( long[] v )
      throws java.rmi.RemoteException;

   public short[] echoShortArray( short[] v )
      throws java.rmi.RemoteException;

   public java.math.BigDecimal[] echoDecimalArray( java.math.BigDecimal[] v )
      throws java.rmi.RemoteException;

   public float[] echoFloatArray( float[] v )
      throws java.rmi.RemoteException;

   public double[] echoDoubleArray( double[] v )
      throws java.rmi.RemoteException;

   public boolean[] echoBooleanArray( boolean[] v )
      throws java.rmi.RemoteException;

   public byte[] echoByteArray( byte[] v )
      throws java.rmi.RemoteException;

   public javax.xml.namespace.QName[] echoQNameArray( javax.xml.namespace.QName[] v )
      throws java.rmi.RemoteException;

   public java.util.Calendar[] echoDateTimeArray( java.util.Calendar[] v )
      throws java.rmi.RemoteException;

}
